@@ -70,11 +70,10 @@ def version():
 
 @cli.command()
 @click.option("--yes", is_flag=True, help="Automatically answer 'yes' to setup prompts")
-@click.option("--teacher", is_flag=True, help="Install in teacher mode")
 @click.option("--config", help="Path to config file (default: ~/.mwc)")
 @click.option("--debug", is_flag=True, help="Show debug-level output")
 @click.pass_context
-def setup(ctx, yes, teacher, config, debug):
+def setup(ctx, yes, config, debug):
     """Set up the MWC command line interface"""
     settings = read_settings(config)
     if debug:
@@ -99,9 +98,11 @@ def setup(ctx, yes, teacher, config, debug):
         token = prompt_mwc_password(settings['mwc_username'])
         settings['mwc_accounts_token'] = token
         status = api.get_status(token)
+    if debug:
+        click.echo(debug_fmt("MWC Accounts Server status:"))
+        click.echo(debug_fmt(str(status)))
     settings['mwc_git_token'] = status['git_token']
     if not yes:
-        settings['role'] = "teacher" if teacher else "student"
         settings['work_dir'] = str(choose_work_dir(settings.get("work_dir")).resolve())
         settings['mwc_site_url'] = choose_mwc_site_url(settings.get('mwc_site_url'))
     curriculum = get_curriculum(settings)
@@ -195,7 +196,7 @@ def update(config):
                     G.update(module, module_dir)
                 except Exception as e:
                     msg =  traceback.format_exception(type(e), e, e.__traceback__)
-                    print(error(''.join(msg)))
+                    click.echo(error(''.join(msg), preformatted=True))
             else:
                 rel_dir = module_dir.resolve().relative_to(mwc_home)
                 click.echo(confirm(f"Initializing {module['slug']} at {rel_dir}."))
@@ -204,7 +205,7 @@ def update(config):
                     G.init_module(module, module_dir)
                 except Exception as e:
                     msg =  traceback.format_exception(type(e), e, e.__traceback__)
-                    click.echo(error(''.join(msg)))
+                    click.echo(error(''.join(msg), preformatted=True))
 
 @cli.command()
 def submit():
@@ -226,3 +227,12 @@ def submit():
     run("git commit", shell=True, capture_output=True, check=True)
     run("git push", shell=True, capture_output=True, check=True)
     click.echo(address("Nice job! All your work in this module has been submitted."))
+
+@cli.group()
+def teach():
+    "Commands for teachers"
+
+@teach.command()
+@click.option("--config", help="Path to config file (default: ~/.mwc)")
+def status():
+    "See status of students in group"
